@@ -1175,7 +1175,7 @@ gconf_peditor_widget_set_guard (GConfPropertyEditor *peditor,
 }
 
 GConfValue *
-gconf_value_int_to_float (const GConfValue *value)
+gconf_value_int_to_float (GConfPropertyEditor *ignored, const GConfValue *value)
 {
 	GConfValue *new_value;
 
@@ -1185,7 +1185,7 @@ gconf_value_int_to_float (const GConfValue *value)
 }
 
 GConfValue *
-gconf_value_float_to_int (const GConfValue *value)
+gconf_value_float_to_int (GConfPropertyEditor *ignored, const GConfValue *value)
 {
 	GConfValue *new_value;
 
@@ -1504,7 +1504,7 @@ peditor_image_set_filename (GConfPropertyEditor *peditor, const gchar *filename)
 		{	
 			if (GTK_IS_IMAGE (l->data))
 				image = GTK_IMAGE (l->data);
-			else if (GTK_IS_LABEL (l->data))
+			else if (GTK_IS_LABEL (l->data) && message == NULL)
 			{
 				gchar *base = g_path_get_basename (filename);
 				gtk_label_set_text (GTK_LABEL (l->data), base);
